require 'erb'
require "safe_yaml"

require "lariat/cli"
require "lariat/github"
require "lariat/issue_writer"
require "lariat/sabotage_stats"
require "lariat/version"

module Lariat
  def self.load_config_from_yaml(relative_config_path)
    full_config_path = ::File.expand_path(relative_config_path)
    yaml_string = ::ERB.new(::File.read(full_config_path)).result
    config = ::YAML.load(yaml_string, :safe => true)
    config.respond_to?(:with_indifferent_access) ? config.with_indifferent_access : config
  end

  def self.load_environment_config_from_yaml(relative_config_path, environment = nil)
    environment ||= ::Lariat.get_environment

    config = load_config_from_yaml(relative_config_path)
    environment_config = config[environment]

    fail "#{environment} environment not found in #{relative_config_path}." unless environment_config
    environment_config
  end

  def self.get_environment
    return "development" unless defined?(::Rails)
    ::Rails.env
  end
end
